##  Overview
SAP LeanIX offers a wide range of standard out-of-the-box [reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD). However, standard reports may be insufficient for your organization.
As a developer, you can build custom reports using the LeanIX Reporting Framework and Command-Line Interface (CLI). With this toolset, you can tailor reports to the needs of your organization.
The reporting toolset consists of two components:
  * [LeanIX Reporting Framework![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fleanix%2Fleanix-reporting "https://github.com/leanix/leanix-reporting"): The framework provides a connection to the SAP LeanIX app, which allows you to create custom reports within SAP LeanIX using the report data and functionality.
  * [LeanIX Reporting CLI![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fleanix%2Fleanix-reporting-cli "https://github.com/leanix/leanix-reporting-cli"): Command-line interface (CLI) tools let you run, build, upload, and publish custom reports to your workspaces and the SAP LeanIX Store.
